``torment.fixtures`` --- Torment Fixtures
=========================================

.. automodule:: torment.fixtures
   
   Fixture
   -------
   .. autoclass:: Fixture
      :members:

   Registration
   ------------
   .. autofunction:: register
